@@ -49,6 +49,24 @@ class AsBias(Enum):
     RIGHT = "RIGHT"
 
 
+class FeedEntry(BaseModel):
+    title: str
+    summary: Optional[str]
+    published_at: datetime
+    url: HttpUrl = Field(alias="link")
+    authors: Optional[str] = Field(alias="author")
+    source_id: UUID
+
+
+class Feed(BaseModel):
+    title: str
+    subtitle: Optional[str]
+    entries: list[FeedEntry]
+    url: HttpUrl = Field(alias="link")
+    updated_at: datetime
+    source_id: UUID
+
+
 class ClusterToLink(SQLModel, table=True):
     cluster_id: Optional[UUID] = Field(default=None, foreign_key="cluster.id", primary_key=True)
     article_id: Optional[UUID] = Field(default=None, foreign_key="article.id", primary_key=True)
